@@ -4,7 +4,13 @@ from .models import PopupPluginModel
 
 
 class DjangocmsPopupAdmin(admin.ModelAdmin):
-    list_display = ("id", "get_page_url", "display_delay", "can_reopen_popup")
+    list_display = (
+        "id",
+        "get_page_url",
+        "display_delay",
+        "can_reopen_popup",
+        "popup_template",
+    )
 
     def get_queryset(self, request):
         print(super(DjangocmsPopupAdmin, self).get_queryset(request))
