@@ -10,7 +10,7 @@ class PopupPluginPublisher(CMSPluginBase):
     module = _("Popup")
     name = _("Popup Container")
     model = PopupPluginModel
-    render_template = "popup/popup_plugin.html"
+    render_template = "popup/base.html"
     allow_children = True
 
     def render(self, context, instance, placeholder):
